@@ -3,7 +3,7 @@ import yaml
 
 
 def folder_config_file(source_file, config):
-    if config['type'] == 'folder' and config.get('config_file'):
+    if config['type'] == 'folder':
         # the config is read *before* its processor is invoked (so no matter what processor you
         # use, it is guaranteed that its config is complete)
         config_path = os.path.join(source_file, config['config_file'])
@@ -14,7 +14,3 @@ def folder_config_file(source_file, config):
             if yaml_config:
                 config.update(yaml_config)
     return config
-
-folder_config_file.defaults = {
-    'config_file': 'config.yaml',
-}
